@@ -1,14 +1,17 @@
 #!/usr/bin/perl -w
 # $File: //member/autrijus/PAR/myldr/file2c.pl $ $Author: autrijus $
-# $Revision: #16 $ $Change: 7306 $ $DateTime: 2003/08/02 12:53:31 $
+# $Revision: #18 $ $Change: 8557 $ $DateTime: 2003/10/26 02:36:51 $
 #
 # Copyright (c) 2002 Mattia Barbon.
 # Copyright (c) 2002 Autrijus Tang.
 # This package is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
-use File::Basename;
 use strict;
+use FindBin;
+use lib "$FindBin::Bin/../lib";
+use File::Basename;
+use PAR::Filter::PodStrip;
 
 my $give_help = 0;
 my $pl_file = shift;
@@ -40,7 +43,8 @@ undef $/;
 my $pl_text = <IN>;
 close IN;
 
-$pl_text = pod_strip($pl_text, basename($pl_file)) if -e $pl_file and $pl_file =~ /\.p[lm]/i;
+PAR::Filter::PodStrip->new->apply(\$pl_text)
+    if -e $pl_file and $pl_file =~ /\.p[lm]/i;
 
 #  make a c-array
 
@@ -91,11 +95,19 @@ sub pod_strip {
     my ($pl_text, $filename) = @_;
 
     local $^W;
+
+    my $data = '';
+    $data = $1 if $pl_text =~ s/((?:^__DATA__$).*)//ms;
+
     my $line = 1;
+    if ($pl_text =~ /^=(?:head\d|pod|begin|item|over|for|back|end)\b/) {
+        $pl_text = "\n$pl_text";
+        $line--;
+    }
     $pl_text =~ s{(
-	(\A|.*?\n)
+	(.*?\n)
 	=(?:head\d|pod|begin|item|over|for|back|end)\b
-	(?:.*?\n)
+	.*?\n
 	(?:=cut[\t ]*[\r\n]*?|\Z)
 	(\r?\n)?
     )}{
@@ -108,7 +120,7 @@ sub pod_strip {
         if length $filename;
     $pl_text =~ s/^#line 1 (.*\n)(#!.*\n)/$2#line 2 $1/g;
 
-    return $pl_text;
+    return $pl_text . $data;
 }
 
 # local variables:
